searchData={"items":[{"type":"module","title":"Exrpc","doc":"Lean Elixir RPC library based on RESP (REdis Serialization Protocol).\n\nTo set up, start `Exrpc.Server` on the server side and `Exrpc.Client` on the client side.","ref":"Exrpc.html"},{"type":"module","title":"Server-side - Exrpc","doc":"```elixir\n# module with function to be called remotely\ndefmodule ServerSideModule do\n  def hello(name), do: \"Hello \"   name\nend\n\n# start link or add child spec to your supervisor\nExrpc.Server.start_link(name: HelloRpc, port: 7379, mfa_list: [&ServerSideModule.hello/1])\n```","ref":"Exrpc.html#module-server-side"},{"type":"module","title":"Client-side - Exrpc","doc":"```elixir\n# start link or add child spec to your supervisor\nExrpc.Client.start_link(name: HelloRpc, host: \"localhost\", port: 7379)\n\n# make a remote function call:\nExrpc.call(HelloRpc, ServerSideModule, :hello, [\"world\"])\n```","ref":"Exrpc.html#module-client-side"},{"type":"function","title":"Exrpc.call/5","doc":"Calls a remote function.","ref":"Exrpc.html#call/5"},{"type":"function","title":"Example - Exrpc.call/5","doc":"iex> Exrpc.call(:my_client, ServerSideModule, :hello, [\"world\"])\n    \"Hello world\"","ref":"Exrpc.html#call/5-example"},{"type":"function","title":"Exrpc.mfa_list/1","doc":"List available remote functions.","ref":"Exrpc.html#mfa_list/1"},{"type":"function","title":"Example - Exrpc.mfa_list/1","doc":"iex> Exrpc.mfa_list(:my_client)\n    [{ServerSideModule, :hello, 1}]","ref":"Exrpc.html#mfa_list/1-example"},{"type":"type","title":"Exrpc.on_call/0","doc":"","ref":"Exrpc.html#t:on_call/0"},{"type":"module","title":"Exrpc.Client","doc":"","ref":"Exrpc.Client.html"},{"type":"function","title":"Exrpc.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Exrpc.Client.html#child_spec/1"},{"type":"function","title":"Exrpc.Client.start_link/1","doc":"","ref":"Exrpc.Client.html#start_link/1"},{"type":"type","title":"Exrpc.Client.t/0","doc":"","ref":"Exrpc.Client.html#t:t/0"},{"type":"module","title":"Exrpc.MFA","doc":"This module provides functions to validate and create `{module, function, arity}` tuple.","ref":"Exrpc.MFA.html"},{"type":"function","title":"Exrpc.MFA.callable?/1","doc":"Check if the given `{module, function, arity}` or `&module.function/arity` is callable.","ref":"Exrpc.MFA.html#callable?/1"},{"type":"function","title":"Examples - Exrpc.MFA.callable?/1","doc":"iex> Exrpc.MFA.callable?({Enum, :into, 2})\n    true\n    iex> Exrpc.MFA.callable?(&Enum.into/2)\n    true\n    iex> Exrpc.MFA.callable?(&Enum.into/255)\n    false\n    iex> Exrpc.MFA.callable?(&Enum.get_rich_quick/1)\n    false","ref":"Exrpc.MFA.html#callable?/1-examples"},{"type":"function","title":"Exrpc.MFA.list/1","doc":"Returns list of mfa tuples from the given module.","ref":"Exrpc.MFA.html#list/1"},{"type":"function","title":"Examples - Exrpc.MFA.list/1","doc":"iex> defmodule Foo do\n    iex>   def bar(), do: :ok\n    iex>   def baz(), do: qux()\n    iex>   defp qux(), do: :ok\n    iex> end\n    iex> Exrpc.MFA.list(Foo)\n    [{Foo, :bar, 0}, {Foo, :baz, 0}]\n    iex> Exrpc.MFA.list(NotAModule)\n    []","ref":"Exrpc.MFA.html#list/1-examples"},{"type":"function","title":"Exrpc.MFA.tuple/1","doc":"Creates `{module, function, arity}` tuple from the given `&module.function/arity` or `{module, function, arity}`.","ref":"Exrpc.MFA.html#tuple/1"},{"type":"function","title":"Examples - Exrpc.MFA.tuple/1","doc":"iex> Exrpc.MFA.tuple({Enum, :into, 2})\n    {Enum, :into, 2}\n    iex> Exrpc.MFA.tuple(&Enum.into/2)\n    {Enum, :into, 2}","ref":"Exrpc.MFA.html#tuple/1-examples"},{"type":"function","title":"Exrpc.MFA.valid?/1","doc":"Check if the given input is in the form of `{module, function, arity}` or `&module.function/arity`.","ref":"Exrpc.MFA.html#valid?/1"},{"type":"function","title":"Examples - Exrpc.MFA.valid?/1","doc":"iex> Exrpc.MFA.valid?({Enum, :into, 2})\n    true\n    iex> Exrpc.MFA.valid?(&Enum.into/2)\n    true\n    iex> Exrpc.MFA.valid?(&Enum.into/255)\n    true\n    iex> Exrpc.MFA.valid?(&Enum.get_rich_quick/1)\n    true\n    iex> Exrpc.MFA.valid?(Enum)\n    false","ref":"Exrpc.MFA.html#valid?/1-examples"},{"type":"module","title":"Exrpc.MFALookup","doc":"Function allowlist and lookup table.\n\nEach functions exposed to clients is assigned a unique integer ID, This allows the server to enforce a function allowlist and the client can make RPC call by transmitting function ID instead of module and function atoms.\n\n**Internal details**: the lookup table is a tuple of two ETS tables, `{mfa2id, id2mfa}`, both of which are owned by the pid that created the table. The first table maps MFAs to IDs, the second table vice versa.","ref":"Exrpc.MFALookup.html"},{"type":"module","title":"Example - Exrpc.MFALookup","doc":"iex> {:ok, lookup} = Exrpc.MFALookup.create([\n    ...>   {Greeter, :hello, 1},\n    ...>   {Greeter, :goodbye, 1}\n    ...> ])\n    iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :hello, 1})\n    0\n    iex> Exrpc.MFALookup.id_to_mfa(lookup, 0)\n    {Greeter, :hello, 1}","ref":"Exrpc.MFALookup.html#module-example"},{"type":"function","title":"Exrpc.MFALookup.create/1","doc":"Create a lookup table from a list of MFAs.","ref":"Exrpc.MFALookup.html#create/1"},{"type":"function","title":"Examples - Exrpc.MFALookup.create/1","doc":"iex> Exrpc.MFALookup.create([])\n    {:error, :empty_list}\n    iex> {:ok, {_mfa2id, _id2mfa}} = Exrpc.MFALookup.create([\n    ...>   {Greeter, :hello, 1},\n    ...>   {Greeter, :goodbye, 1}\n    ...> ])","ref":"Exrpc.MFALookup.html#create/1-examples"},{"type":"function","title":"Exrpc.MFALookup.id_to_mfa/2","doc":"Get MFA by ID.","ref":"Exrpc.MFALookup.html#id_to_mfa/2"},{"type":"function","title":"Examples - Exrpc.MFALookup.id_to_mfa/2","doc":"iex> {:ok, lookup} = Exrpc.MFALookup.create([\n    ...>   {Greeter, :hello, 1},\n    ...>   {Greeter, :goodbye, 1}\n    ...> ])\n    iex> Exrpc.MFALookup.id_to_mfa(lookup, 0)\n    {Greeter, :hello, 1}\n    iex> Exrpc.MFALookup.id_to_mfa(lookup, 1)\n    {Greeter, :goodbye, 1}\n    iex> Exrpc.MFALookup.id_to_mfa(lookup, 2)\n    nil","ref":"Exrpc.MFALookup.html#id_to_mfa/2-examples"},{"type":"function","title":"Exrpc.MFALookup.mfa_to_id/2","doc":"Get the ID of an MFA.","ref":"Exrpc.MFALookup.html#mfa_to_id/2"},{"type":"function","title":"Examples - Exrpc.MFALookup.mfa_to_id/2","doc":"iex> {:ok, lookup} = Exrpc.MFALookup.create([\n    ...>   {Greeter, :hello, 1},\n    ...>   {Greeter, :goodbye, 1}\n    ...> ])\n    iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :hello, 1})\n    0\n    iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :goodbye, 1})\n    1\n    iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :heyyyy, 1})\n    nil","ref":"Exrpc.MFALookup.html#mfa_to_id/2-examples"},{"type":"function","title":"Exrpc.MFALookup.to_list/1","doc":"Get a list of MFAs.","ref":"Exrpc.MFALookup.html#to_list/1"},{"type":"function","title":"Examples - Exrpc.MFALookup.to_list/1","doc":"iex> {:ok, lookup} = Exrpc.MFALookup.create([\n    ...>   {Greeter, :hello, 1},\n    ...>   {Greeter, :goodbye, 1}\n    ...> ])\n    iex> Exrpc.MFALookup.to_list(lookup)\n    [{Greeter, :hello, 1}, {Greeter, :goodbye, 1}]","ref":"Exrpc.MFALookup.html#to_list/1-examples"},{"type":"type","title":"Exrpc.MFALookup.t/0","doc":"","ref":"Exrpc.MFALookup.html#t:t/0"},{"type":"module","title":"Exrpc.Server","doc":"","ref":"Exrpc.Server.html"},{"type":"function","title":"Exrpc.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Exrpc.Server.html#child_spec/1"},{"type":"function","title":"Exrpc.Server.start_link/1","doc":"","ref":"Exrpc.Server.html#start_link/1"}],"content_type":"text/markdown"}